==> gnome-control-center-3.14.3.tar.xz: gnome-control-center-3.14.3/panels/background/gdesktop-enums-types.h <==



#ifndef __GDESKTOP_ENUMS_TYPES_H__
#define __GDESKTOP_ENUMS_TYPES_H__

#include <glib-object.h>

G_BEGIN_DECLS
/* enumerations from "/usr/include/gsettings-desktop-schemas/gdesktop-enums.h" */
GType g_desktop_proxy_mode_get_type (void) G_GNUC_CONST;
#define G_DESKTOP_TYPE_DESKTOP_PROXY_MODE (g_desktop_proxy_mode_get_type())
GType g_desktop_toolbar_style_get_type (void) G_GNUC_CONST;
#define G_DESKTOP_TYPE_DESKTOP_TOOLBAR_STYLE (g_desktop_toolbar_style_get_type())
GType g_desktop_toolbar_icon_size_get_type (void) G_GNUC_CONST;
#define G_DESKTOP_TYPE_DESKTOP_TOOLBAR_ICON_SIZE (g_desktop_toolbar_icon_size_get_type())
GType g_desktop_background_style_get_type (void) G_GNUC_CONST;
#define G_DESKTOP_TYPE_DESKTOP_BACKGROUND_STYLE (g_desktop_background_style_get_type())
GType g_desktop_background_shading_get_type (void) G_GNUC_CONST;
#define G_DESKTOP_TYPE_DESKTOP_BACKGROUND_SHADING (g_desktop_background_shading_get_type())
GType g_desktop_mouse_dwell_mode_get_type (void) G_GNUC_CONST;
#define G_DESKTOP_TYPE_DESKTOP_MOUSE_DWELL_MODE (g_desktop_mouse_dwell_mode_get_type())
GType g_desktop_mouse_dwell_direction_get_type (void) G_GNUC_CONST;
#define G_DESKTOP_TYPE_DESKTOP_MOUSE_DWELL_DIRECTION (g_desktop_mouse_dwell_direction_get_type())
GType g_desktop_clock_format_get_type (void) G_GNUC_CONST;
#define G_DESKTOP_TYPE_DESKTOP_CLOCK_FORMAT (g_desktop_clock_format_get_type())
GType g_desktop_screensaver_mode_get_type (void) G_GNUC_CONST;
#define G_DESKTOP_TYPE_DESKTOP_SCREENSAVER_MODE (g_desktop_screensaver_mode_get_type())
GType g_desktop_magnifier_mouse_tracking_mode_get_type (void) G_GNUC_CONST;
#define G_DESKTOP_TYPE_DESKTOP_MAGNIFIER_MOUSE_TRACKING_MODE (g_desktop_magnifier_mouse_tracking_mode_get_type())
GType g_desktop_magnifier_focus_tracking_mode_get_type (void) G_GNUC_CONST;
#define G_DESKTOP_TYPE_DESKTOP_MAGNIFIER_FOCUS_TRACKING_MODE (g_desktop_magnifier_focus_tracking_mode_get_type())
GType g_desktop_magnifier_caret_tracking_mode_get_type (void) G_GNUC_CONST;
#define G_DESKTOP_TYPE_DESKTOP_MAGNIFIER_CARET_TRACKING_MODE (g_desktop_magnifier_caret_tracking_mode_get_type())
GType g_desktop_magnifier_screen_position_get_type (void) G_GNUC_CONST;
#define G_DESKTOP_TYPE_DESKTOP_MAGNIFIER_SCREEN_POSITION (g_desktop_magnifier_screen_position_get_type())
GType g_desktop_titlebar_action_get_type (void) G_GNUC_CONST;
#define G_DESKTOP_TYPE_DESKTOP_TITLEBAR_ACTION (g_desktop_titlebar_action_get_type())
GType g_desktop_focus_mode_get_type (void) G_GNUC_CONST;
#define G_DESKTOP_TYPE_DESKTOP_FOCUS_MODE (g_desktop_focus_mode_get_type())
GType g_desktop_focus_new_windows_get_type (void) G_GNUC_CONST;
#define G_DESKTOP_TYPE_DESKTOP_FOCUS_NEW_WINDOWS (g_desktop_focus_new_windows_get_type())
GType g_desktop_visual_bell_type_get_type (void) G_GNUC_CONST;
#define G_DESKTOP_TYPE_DESKTOP_VISUAL_BELL_TYPE (g_desktop_visual_bell_type_get_type())
GType g_desktop_location_accuracy_level_get_type (void) G_GNUC_CONST;
#define G_DESKTOP_TYPE_DESKTOP_LOCATION_ACCURACY_LEVEL (g_desktop_location_accuracy_level_get_type())
/* enumerations from "cc-background-item.h" */
GType cc_background_item_flags_get_type (void) G_GNUC_CONST;
#define G_DESKTOP_TYPE_BACKGROUND_ITEM_FLAGS (cc_background_item_flags_get_type())
G_END_DECLS

#endif /* __GDESKTOP_ENUMS_TYPES_H__ */

==> gnome-control-center-3.15.4.tar.xz: gnome-control-center-3.15.4/panels/background/gdesktop-enums-types.h <==



#ifndef __GDESKTOP_ENUMS_TYPES_H__
#define __GDESKTOP_ENUMS_TYPES_H__

#include <glib-object.h>

G_BEGIN_DECLS
/* enumerations from "/home/rmatos/Source/git.gnome.org/install/include/gsettings-desktop-schemas/gdesktop-enums.h" */
GType g_desktop_proxy_mode_get_type (void) G_GNUC_CONST;
#define G_DESKTOP_TYPE_DESKTOP_PROXY_MODE (g_desktop_proxy_mode_get_type())
GType g_desktop_toolbar_style_get_type (void) G_GNUC_CONST;
#define G_DESKTOP_TYPE_DESKTOP_TOOLBAR_STYLE (g_desktop_toolbar_style_get_type())
GType g_desktop_toolbar_icon_size_get_type (void) G_GNUC_CONST;
#define G_DESKTOP_TYPE_DESKTOP_TOOLBAR_ICON_SIZE (g_desktop_toolbar_icon_size_get_type())
GType g_desktop_background_style_get_type (void) G_GNUC_CONST;
#define G_DESKTOP_TYPE_DESKTOP_BACKGROUND_STYLE (g_desktop_background_style_get_type())
GType g_desktop_background_shading_get_type (void) G_GNUC_CONST;
#define G_DESKTOP_TYPE_DESKTOP_BACKGROUND_SHADING (g_desktop_background_shading_get_type())
GType g_desktop_mouse_dwell_mode_get_type (void) G_GNUC_CONST;
#define G_DESKTOP_TYPE_DESKTOP_MOUSE_DWELL_MODE (g_desktop_mouse_dwell_mode_get_type())
GType g_desktop_mouse_dwell_direction_get_type (void) G_GNUC_CONST;
#define G_DESKTOP_TYPE_DESKTOP_MOUSE_DWELL_DIRECTION (g_desktop_mouse_dwell_direction_get_type())
GType g_desktop_clock_format_get_type (void) G_GNUC_CONST;
#define G_DESKTOP_TYPE_DESKTOP_CLOCK_FORMAT (g_desktop_clock_format_get_type())
GType g_desktop_screensaver_mode_get_type (void) G_GNUC_CONST;
#define G_DESKTOP_TYPE_DESKTOP_SCREENSAVER_MODE (g_desktop_screensaver_mode_get_type())
GType g_desktop_magnifier_mouse_tracking_mode_get_type (void) G_GNUC_CONST;
#define G_DESKTOP_TYPE_DESKTOP_MAGNIFIER_MOUSE_TRACKING_MODE (g_desktop_magnifier_mouse_tracking_mode_get_type())
GType g_desktop_magnifier_focus_tracking_mode_get_type (void) G_GNUC_CONST;
#define G_DESKTOP_TYPE_DESKTOP_MAGNIFIER_FOCUS_TRACKING_MODE (g_desktop_magnifier_focus_tracking_mode_get_type())
GType g_desktop_magnifier_caret_tracking_mode_get_type (void) G_GNUC_CONST;
#define G_DESKTOP_TYPE_DESKTOP_MAGNIFIER_CARET_TRACKING_MODE (g_desktop_magnifier_caret_tracking_mode_get_type())
GType g_desktop_magnifier_screen_position_get_type (void) G_GNUC_CONST;
#define G_DESKTOP_TYPE_DESKTOP_MAGNIFIER_SCREEN_POSITION (g_desktop_magnifier_screen_position_get_type())
GType g_desktop_titlebar_action_get_type (void) G_GNUC_CONST;
#define G_DESKTOP_TYPE_DESKTOP_TITLEBAR_ACTION (g_desktop_titlebar_action_get_type())
GType g_desktop_focus_mode_get_type (void) G_GNUC_CONST;
#define G_DESKTOP_TYPE_DESKTOP_FOCUS_MODE (g_desktop_focus_mode_get_type())
GType g_desktop_focus_new_windows_get_type (void) G_GNUC_CONST;
#define G_DESKTOP_TYPE_DESKTOP_FOCUS_NEW_WINDOWS (g_desktop_focus_new_windows_get_type())
GType g_desktop_visual_bell_type_get_type (void) G_GNUC_CONST;
#define G_DESKTOP_TYPE_DESKTOP_VISUAL_BELL_TYPE (g_desktop_visual_bell_type_get_type())
GType g_desktop_location_accuracy_level_get_type (void) G_GNUC_CONST;
#define G_DESKTOP_TYPE_DESKTOP_LOCATION_ACCURACY_LEVEL (g_desktop_location_accuracy_level_get_type())
GType g_desktop_touchpad_scroll_method_get_type (void) G_GNUC_CONST;
#define G_DESKTOP_TYPE_DESKTOP_TOUCHPAD_SCROLL_METHOD (g_desktop_touchpad_scroll_method_get_type())
GType g_desktop_touchpad_handedness_get_type (void) G_GNUC_CONST;
#define G_DESKTOP_TYPE_DESKTOP_TOUCHPAD_HANDEDNESS (g_desktop_touchpad_handedness_get_type())
GType g_desktop_device_send_events_get_type (void) G_GNUC_CONST;
#define G_DESKTOP_TYPE_DESKTOP_DEVICE_SEND_EVENTS (g_desktop_device_send_events_get_type())
/* enumerations from "cc-background-item.h" */
GType cc_background_item_flags_get_type (void) G_GNUC_CONST;
#define G_DESKTOP_TYPE_BACKGROUND_ITEM_FLAGS (cc_background_item_flags_get_type())
G_END_DECLS

#endif /* __GDESKTOP_ENUMS_TYPES_H__ */
